@@ -60,13 +60,10 @@ class NuitkaTarget(SingleBuildTarget):
             self.out_dir = self.out_dir / nuitka_subdir
         self.dist_dir: Path = self.out_dir / f'{self.package_name}.dist'
         self.singlefile: bool = single_file
-        self.executable_mangled: Path = self.dist_dir / \
-            self.package_name if not single_file else (
-                self.out_dir / self.package_name).with_suffix('.bin')
+        self.executable_mangled: Path = self.dist_dir / self.package_name if not single_file else (self.out_dir / self.package_name).with_suffix('.bin')
 
         if os.name == 'nt':
-            self.executable_mangled = self.executable_mangled.with_suffix(
-                '.exe')
+            self.executable_mangled = self.executable_mangled.with_suffix('.exe')
 
         self.windows_disable_console: bool = False
         #: See Nuitka --windows-icon-from-ico for format
@@ -83,8 +80,7 @@ class NuitkaTarget(SingleBuildTarget):
 
         self.linux_onefile_icon: Optional[Union[str, Path]] = None
 
-        super().__init__(target=str(self.executable_mangled),
-                         files=files, dependencies=dependencies)
+        super().__init__(target=str(self.executable_mangled), files=list(map(str, files)), dependencies=list(map(str, dependencies)))
 
         self.included_packages: Set[str] = set()
         self.enabled_plugins: Set[str] = set()
@@ -103,16 +99,13 @@ class NuitkaTarget(SingleBuildTarget):
                 NuitkaPlugins.loadPlugins()
                 # print(repr(NuitkaPlugins.getActivePlugins()))
                 for plugin_name in sorted(NuitkaPlugins.plugin_name2plugin_classes):
-                    plugin: NuitkaPluginBase = NuitkaPlugins.plugin_name2plugin_classes[
-                        plugin_name][0]
+                    plugin: NuitkaPluginBase = NuitkaPlugins.plugin_name2plugin_classes[plugin_name][0]
                     if plugin.isAlwaysEnabled():
-                        self._CACHED_ALWAYS_ENABLED_PLUGINS.add(
-                            plugin.plugin_name)
+                        self._CACHED_ALWAYS_ENABLED_PLUGINS.add(plugin.plugin_name)
             except Exception as e:
                 log.critical('Error interfacing with Nuitka:')
                 log.critical(e)
-            log.debug(
-                f'_CACHED_ALWAYS_ENABLED_PLUGINS = {self._CACHED_ALWAYS_ENABLED_PLUGINS!r}')
+            log.debug(f'_CACHED_ALWAYS_ENABLED_PLUGINS = {self._CACHED_ALWAYS_ENABLED_PLUGINS!r}')
         return self._CACHED_ALWAYS_ENABLED_PLUGINS
 
     def build(self):
@@ -171,5 +164,4 @@ class NuitkaTarget(SingleBuildTarget):
         nuitka_cmd: List[str] = [str(sys.executable), '-m', 'nuitka']
         nuitka_cmd += opts
         nuitka_cmd.append(str(self.entry_point))
-        os_utils.cmd(nuitka_cmd, echo=True, show_output=True,
-                     critical=True, globbify=False)
+        os_utils.cmd(nuitka_cmd, echo=True, show_output=True, critical=True, globbify=False)
